#
# spec file for package python-stomp.py
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-stomp.py
Version:        8.1.0
Release:        1.9
Summary:        Python STOMP client
License:        Apache-2.0
URL:            https://github.com/jasonrbriggs/stomp.py
# using github archive for docs
#Source0:        https://github.com/jasonrbriggs/stomp.py/archive/v%%{version}.tar.gz#/%%{name}-%%{version}.tar.gz
#github is missing the tag: https://github.com/jasonrbriggs/stomp.py/issues/415
Source0:        https://files.pythonhosted.org/packages/source/s/stomp.py/stomp.py-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  fdupes
BuildRequires:  python-rpm-generators
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
%{?python_enable_dependency_generator}
BuildArch:      noarch
%python_subpackages

%description
A Python client library for accessing messaging servers (such as ActiveMQ, Apollo or RabbitMQ) using the STOMP protocol versions 1.0, 1.1 and 1.2. It can also be run as a standalone, command-line client for testing.

%prep
%setup -q -n stomp.py-%{version}
sed -i 's/\^/>=/' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/stomp
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative stomp

%postun
%python_uninstall_alternative stomp

%files %{python_files}
%doc README.rst
# CHANGELOG.md
%license LICENSE
%python_alternative %{_bindir}/stomp
%{python_sitelib}/stomp/
%{python_sitelib}/stomp_py-%{version}*-info

%changelog
* Sat Mar 11 2023 Sebastian Wagner <sebix@sebix.at>
- Update to version 8.1.0:
  - Remove ssl expiration check as per PR: #380
  - Change deprecated PROTOCOL_TLS to PROTOCOL_TLS_CLIENT
  - Mock dns responses for testing: #383
  - Support for connection over websocket: #395
  - Add default arg for try_setsockopt (#391)
  - Updating log levels (#401)
  - General tidy up of log messages
* Tue May 24 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 8.0.1:
  * Change code to use cryptography lib rather than PyOpenSSL (which is not recommended for use any more - discussed here: https://github.com/jasonrbriggs/stomp.py/issues/378)
* Mon Feb 14 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- Relieve python dependencies (replace ^ with >=).
* Sun Feb  6 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove need for two source tarballs, use only the github one with pyproject macros
- update to version 8.0.0:
  * Add support for backwards compatible CONNECT in 1.1 and 1.2 protocols (https://github.com/jasonrbriggs/stomp.py/pull/348)
  * Flip DEFAULT_SSL_VERSION to use ssl.PROTOCOL_TLS rather than ssl.PROTOCOL_TLSv1
  * Check SSL certificate for expiry if PyOpenSSL is installed
  * Remove deprecated constructor params (use_ssl, and other ssl params)
  * Minor cleanup (remove debian packaging config, since it didn't work any more)
  * Add log_to_stdout method to force command line logging to stdout (useful for testing)
  * Various updates for docker testing
  * Add mac keepalive functionality
  * Minor update to daemon attribute (https://github.com/jasonrbriggs/stomp.py/pull/361)
  * Fix issue with heartbeat listener disconnecting the socket (https://github.com/jasonrbriggs/stomp.py/issues/219 - https://github.com/jasonrbriggs/stomp.py/pull/369)
* Mon Apr 12 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 7.0.0:
  (from v6.1.1):
  * Add host bind port patch (https://github.com/jasonrbriggs/stomp.py/issues/331)
  * Tidy up based on pycharm suggestions
  * Change quotes to be consistent (" rather than ')
  (from v6.1.0):
  * Remove traceback logging (https://github.com/jasonrbriggs/stomp.py/pull/290)
  * Add support for \r\n EOL handling (as per [stomp protocol v1.2](http://stomp.github.io/stomp-specification-1.2.html#Augmented_BNF))
  * Remove heartbeat loop sleep (issue https://github.com/jasonrbriggs/stomp.py/issues/297, https://github.com/jasonrbriggs/stomp.py/pull/298)
  * Update version number using the makefile and the poetry version command
  * Add `original_headers` access to the Frame so that you can get the original value of a header even if a listener modifies it (issue: https://github.com/jasonrbriggs/stomp.py/issues/300, PR https://github.com/jasonrbriggs/stomp.py/pull/309)
  * Fix for reconnect failures (https://github.com/jasonrbriggs/stomp.py/pull/295)
  * Fix for double disconnect notifications causing issues with reconnection
  * Add 'verbose' to stomp.logging (and defaulting the value to False). Log lines which dump the stacktrace now use that variable - except for a couple of cases (set stomp.logging.verbose = True to change back to the previous behaviour)
* Mon Apr  5 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 6.1.1:
  * Add host bind port patch (https://github.com/jasonrbriggs/stomp.py/issues/331)
  * Tidy up based on pycharm suggestions
  * Change quotes to be consistent (" rather than ')
* Mon Jul 13 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 6.1.0:
  * Remove traceback logging (https://github.com/jasonrbriggs/stomp.py/pull/290)
  * Add support for \r\n EOL handling (as per [stomp protocol v1.2](http://stomp.github.io/stomp-specification-1.2.html#Augmented_BNF))
  * Remove heartbeat loop sleep (issue https://github.com/jasonrbriggs/stomp.py/issues/297, https://github.com/jasonrbriggs/stomp.py/pull/298)
  * Update version number using the makefile and the poetry version command
  * Add `original_headers` access to the Frame so that you can get the original value of a header even if a listener modifies it (issue: https://github.com/jasonrbriggs/stomp.py/issues/300, PR https://github.com/jasonrbriggs/stomp.py/pull/309)
  * Fix for reconnect failures (https://github.com/jasonrbriggs/stomp.py/pull/295)
  * Fix for double disconnect notifications causing issues with reconnection
  * Add 'verbose' to stomp.logging (and defaulting the value to False). Log lines which dump the stacktrace now use that variable - except for a couple of cases (set stomp.logging.verbose = True to change back to the previous behaviour)
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Feb 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 6.0.0:
  * Update to not allow a null (None) listener when calling set_listener (minor code "smell" tidy up)
  * Change get_ssl call in connect to be consistent with transport method
  * Add a sleep to the heartbeat loop
  * Minor change to make quote-use more consistent (replace single with double in most places)
  * Change build to use [Python Poetry](https://python-poetry.org/)
  * Test coverage improvement
  * Threading fix (is_alive) - https://github.com/jasonrbriggs/stomp.py/issues/286
* Sat Jan 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 5.0.1:
  * Fix logging simplification code (should not be logging to root appender - https://github.com/jasonrbriggs/stomp.py/issues/275)
* Wed Jan  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- dropped Python 2 support, not supported by the package
- update to version 5.0.0:
  * Fix for credentials exposure (https://github.com/jasonrbriggs/stomp.py/pull/244)
  * Check for ``STOMP_SKIP_HOSTNAME_SCAN`` environment variable before extending ``LOCALHOST_NAMES``
  * Remove python2 backwards compatibility
  * Update dockerfile for better local testing
  * Fix docker and travis setup, so there are consistent builds both locally and via CI
  * Drop deprecated start/stop methods from connection (issue https://github.com/jasonrbriggs/stomp.py/issues/257)
  * Fix for missing return in get_ssl (https://github.com/jasonrbriggs/stomp.py/pull/258)
  * Clear heartbeat event after heartbeat loop ends (https://github.com/jasonrbriggs/stomp.py/pull/260)
  * Update listener to move receive/message_received/heartbeat_received vars inside the 'with' blocks (https://github.com/jasonrbriggs/stomp.py/pull/252)
  * Simplify logging calls
  * Tidy up listeners (correct the behaviour of TestListener)
  * Fix problem with double-disconnect notification (ihttps://github.com/jasonrbriggs/stomp.py/issues/245)
  * Add facility for PrintingListener to write to log rather than print statements
* Thu Apr 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.1.22
  * Infinite retry attempts
  * Terminate heartbeat thread on shutdown
  * Remove unused wait_on_receipt parameter
  * Reduce verbosity in logging to not include headers unless debug
  level is turned on (potential security issue)
  * Fix for disconnect receipt usage in transport
  * Add __enter__/__exit__ to Connection so it can be used as a
  context
  * Additional ssl options
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Jul  7 2018 sebix+novell.com@sebix.at
- update to version 4.1.20:
  * Fix for deadlock issue (https://github.com/jasonrbriggs/stomp.py/issues/197)
  * Fix for encoding issue (https://github.com/jasonrbriggs/stomp.py/issues/195)
  * Fix for reconnect issue (https://github.com/jasonrbriggs/stomp.py/issues/202)
* Sun Feb 18 2018 sebix+novell.com@sebix.at
- initial package for version 4.1.20
